package BBS::Handler;
our $NOLOAD = 1;

#===========================================================
# BBS.pm サブモジュール【 ハンドラ制御 】
#
our $VERSION = '0001.20210225.2358';		# 新版
#===========================================================
use strict;
use warnings;
use utf8;
use Data::Dumper;
use Debug;

#==================================================
# ■ コンストラクタ
# r = new( func )
#
# [引数]
# func : サブルーチン(省略可)
#
# [返り値]
# r = オブジェクト
#
# 引数を省略した場合はundefを返すルーチンが設定される。
#==================================================
sub new {
	#printf "\n(%s::new [%s]) ", __PACKAGE__, Debug::_caller(caller);		# ????
	my $class = shift;
	my $func = shift;						# サブルーチン
	my $self = {};
	bless($self, $class);
	$self->_init();
	$self->set($func) if (defined($func));									# 引数が指定されていたらルーチンをセットしてみる
	return $self;
}

#==================================================
# ■ 属性の初期化
# _init()
#==================================================
sub _init {
	my $self = shift;
	$self->{'Func'}	= sub { return };
}

#==================================================
# ■ ルーチンをセット
# r = set( func )
#
# [引数]
# func : サブルーチン
#
# [返り値]
# r =
# undef : 失敗
#     1 : 成功
#==================================================
sub set {
	#printf "\n(%s::set [%s]) ", __PACKAGE__, Debug::_caller(caller);		# ????
	my $self = shift;
	my $func = shift;						# サブルーチン

	return unless defined($func);											# 引数が定義されていない(undef)
	return unless (ref($func) eq 'CODE');									# 引数がサブルーチンでない(undef)

	$self->{'Func'} = $func;

	#print "\n\t **".Dumper( $self->{'Func'} );								# ???? 内容
	return 1;
}

#==================================================
# ■ ルーチンを呼び出す
# call( arg )
#
# [引数]
# arg
#
# [返り値]
# なし
#==================================================
sub call {
	#printf "\n(%s::call [%s]) ", __PACKAGE__, Debug::_caller(caller);		# ????
	my $self = shift;

	return &{ $self->{'Func'} }(@_);										# ルーチンを実行
}

#printf("(%s) [ %s ]\n", $VERSION, __PACKAGE__ ) if ( defined($::DEBUG) && $::DEBUG >= 1 );

#================================================================
=pod

=encoding utf8

=head1 スクリプト名

BBS::Handler - BBS.pm サブモジュール【 ハンドラ制御 】

=head1 著者

naoit0 <https://www.naoit0.com/projects/bbs_pm/>

=cut
1;