package BBS::IO::Output;
our $NOLOAD = 1;
#===========================================================
# BBS.pm コアシステム
# サブモジュール 【 出力制御 】
# 
our $VERSION = "----.20210227.2211";		# 新版
#===========================================================
use utf8;
use strict;
use warnings;
use Encode qw( encode decode );
use Data::Dumper;
use Debug;

#==================================================
# ■ コンストラクタ
# new()
#==================================================
sub new {
	my $class = shift;
	my $self = { @_ };
	bless($self, $class);
	$self->_init();
	return $self;
}

#==================================================
# ■ 属性の初期化
# _init()
#==================================================
sub _init {
	my $self = shift;

		$self->{'Buffer'} = [];
}


#==================================================
# ■ データをバッファに取り込む
# size = store( data );
# 
# [引数]
#    data = データ
# 
# [返り値]
#  size = 取り込み後のデータ長
# 
#==================================================
sub store {
	printf "\n(%s::store [%s]) ", __PACKAGE__, Debug::_caller(caller) if ($::DEBUG =~ /a/);		# ????
	my $self = shift;
	my $data = shift;							# 取り込むデータ

	push(@{ $self->{'Buffer'} }, $data );
	return;
}

#==================================================
# ■ バッファからデータを取り出す
# size = emit( data );
# 
# [引数]
#    data = データ
# 
# [返り値]
#  size = 取り込み後のデータ長
# 
#==================================================
sub emit {
	printf "\n(%s::emit [%s]) ", __PACKAGE__, Debug::_caller(caller) if ($::DEBUG =~ /a/);		# ????
	my $self = shift;

	my $data = shift( @{ $self->{'Buffer'} } );
	return $data;
}

printf("\n(%s) [ %s ] ", $VERSION, __PACKAGE__ ) if ( $::DEBUG =~ /a/ );

#================================================================
=pod

=encoding utf8

=head1 スクリプト名

Output.pm - BBS.pm サブモジュール 【 出力制御 】

=head1 著者

naoit0 <https://www.naoit0.com/projects/bbs_pm/>

=cut
1;